package com.nineoldandroids_b4a.animation;

import com.nineoldandroids_b4a.animation.TimeAnimator.TimeListener;

import anywheresoftware.b4a.BA;

@BA.Events(values = { "Start", "Cancel", "End", "TimeUpdate(TotalTime As Long, DeltaTime As Long)" })
@BA.ShortName(value = "noaTimeAnimator")
public class TimeAnimWrapper {

	protected TimeAnimator TA;

	/**
	 * Initializes a TimeAnimator.
	 * There is no duration, interpolation, or object value-setting with this Animator.
	 * Instead, it is simply started, after which it proceeds to send out events on every animation
	 * frame to its TimeUpdate listener, with information about the total elapsed time, and the
	 * elapsed time since the previous animation frame.
	 */
	public TimeAnimWrapper Initialize(final BA ba, String EventPrefix) {
		TA = new TimeAnimator();
		TA.initEvents(ba, EventPrefix);
		final String EventName = EventPrefix.toLowerCase(BA.cul) + "_timeupdate";
		final TimeAnimWrapper _THIS = this;
		if (ba.subExists(EventName)) {
			TA.setTimeListener(new TimeListener() {
				@Override
				public void onTimeUpdate(TimeAnimator animation, long totalTime, long deltaTime)
				{
					ba.raiseEvent2(_THIS, false, EventName, true, new Object[] {totalTime, deltaTime});
				}
			});
		}
		return this;
	}

	/**
	 * Starts this Animator.
	 * Calls to Start after the first are ignored. If you want to restart the animation, call Cancel
	 * or End before.
	 */
	public void Start() {
		TA.Start();
	}

	/**
	 * Cancels this Animator.
	 */
	public void Cancel() {
		TA.Cancel();
	}

	/**
	 * Ends this Animator.
	 */
	public void End() {
		TA.End();
	}

	/**
	 * Returns whether this Animator is currently running (having been started and gone past any
	 * initial startDelay period and not yet ended).
	 */
	public boolean isRunning() {
		return TA.isRunning();
	}

	/**
	 * Returns whether this Animator has been started and not yet ended.
	 */
	public boolean isStarted() {
		return TA.isStarted();
	}

	/**
	 * The amount of time, in milliseconds, to delay starting the animation after Start() is called.
	 */
	public long getStartDelay() {
		return TA.getStartDelay();
	}
	public void setStartDelay(long startDelay) {
		TA.setStartDelay(startDelay);
	}

	/**
	 * The amount of time, in milliseconds, between each frame of the animation. This is a
	 * requested time that the animation will attempt to honor, but the actual delay between
	 * frames may be different, depending on system load and capabilities.
	 * NOTE: the same delay is applied to all animations, since they are all run off of a
	 * single timing loop.
	 */
	public static long getFrameDelay() {
		return ValueAnimator.getFrameDelay();
	}
	public static void setFrameDelay(long frameDelay) {
		ValueAnimator.setFrameDelay(frameDelay);
	}
}
